@@ -22,11 +22,8 @@
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
 from typing import Any
-from typing import Iterator
-from typing import KeysView
 from typing import Literal
 from typing import NamedTuple
-from typing import Optional
 
 import calendar
 import datetime
@@ -35,6 +32,8 @@ import logging
 import sqlite3 as sqlite
 import time
 from collections import namedtuple
+from collections.abc import Iterator
+from collections.abc import KeysView
 
 from nbxmpp import JID
 from nbxmpp.structs import CommonError
@@ -100,17 +99,17 @@ class JidsTableRow(NamedTuple):
 
 
 class ConversationRow(NamedTuple):
+    log_line_id: int
     contact_name: str | None
+    occupant_id: str | None
+    real_jid: JID | None
     time: float
     kind: int
-    show: int
     message: str
-    subject: str
-    additional_data: AdditionalDataDict | None
-    log_line_id: int
-    message_id: str
-    stanza_id: str
     error: CommonError
+    additional_data: AdditionalDataDict | None
+    stanza_id: str
+    message_id: str
     marker: str
 
 
@@ -162,10 +161,11 @@ class MessageExportRow(NamedTuple):
 
 
 class MessageArchiveStorage(SqliteStorage):
-    def __init__(self):
+    def __init__(self, in_memory: bool = False):
+        path = None if in_memory else configpaths.get('LOG_DB')
         SqliteStorage.__init__(self,
                                log,
-                               configpaths.get('LOG_DB'),
+                               path,
                                ARCHIVE_SQL_STATEMENT)
 
         self._jid_ids: dict[JID, JidsTableRow] = {}
@@ -283,7 +283,7 @@ class MessageArchiveStorage(SqliteStorage):
             self._jid_ids[row.jid] = row
             self._jid_ids_reversed[row.jid_id] = row
 
-    def get_jid_from_id(self, jid_id: int) -> Optional[JidsTableRow]:
+    def get_jid_from_id(self, jid_id: int) -> JidsTableRow | None:
         # Use get as a fail-safe for cases where the JID ID table is incomplete
         return self._jid_ids_reversed.get(jid_id)
 
@@ -306,8 +306,8 @@ class MessageArchiveStorage(SqliteStorage):
     @timeit
     def get_jid_id(self,
                    jid: JID,
-                   kind: Optional[KindConstant] = None,
-                   type_: Optional[JIDConstant] = None
+                   kind: KindConstant | None = None,
+                   type_: JIDConstant | None = None
                    ) -> int:
         '''
         Get the jid id from a jid.
@@ -382,10 +382,19 @@ class MessageArchiveStorage(SqliteStorage):
             time_order = 'AND time > ? ORDER BY time ASC, log_line_id ASC'
 
         sql = '''
-            SELECT contact_name, time, kind, show, message, subject,
-                   additional_data, log_line_id, message_id, stanza_id,
-                   error as "error [common_error]",
-                   marker as "marker [marker]"
+            SELECT
+                log_line_id,
+                contact_name,
+                occupant_id,
+                real_jid as "real_jid [jid]",
+                time,
+                kind,
+                message,
+                error as "error [common_error]",
+                additional_data,
+                stanza_id,
+                message_id,
+                marker as "marker [marker]"
             FROM logs NATURAL JOIN jids WHERE jid IN ({jids})
             AND account_id = {account_id}
             AND kind NOT IN ({kinds})
@@ -456,13 +465,22 @@ class MessageArchiveStorage(SqliteStorage):
         jids = [jid]
         account_id = self.get_account_id(account)
         kinds = map(str, [KindConstant.ERROR])
-        n_lines = 20
+        n_lines = 50
 
         sql_before = '''
-            SELECT contact_name, time, kind, show, message, subject,
-                   additional_data, log_line_id, message_id, stanza_id,
-                   error as "error [common_error]",
-                   marker as "marker [marker]"
+            SELECT
+                log_line_id,
+                contact_name,
+                occupant_id,
+                real_jid as "real_jid [jid]",
+                time,
+                kind,
+                message,
+                error as "error [common_error]",
+                additional_data,
+                stanza_id,
+                message_id,
+                marker as "marker [marker]"
             FROM logs NATURAL JOIN jids WHERE jid IN ({jids})
             AND account_id = {account_id}
             AND kind NOT IN ({kinds})
@@ -473,10 +491,19 @@ class MessageArchiveStorage(SqliteStorage):
                        account_id=account_id,
                        kinds=', '.join(kinds))
         sql_at_after = '''
-            SELECT contact_name, time, kind, show, message, subject,
-                   additional_data, log_line_id, message_id, stanza_id,
-                   error as "error [common_error]",
-                   marker as "marker [marker]"
+            SELECT
+                log_line_id,
+                contact_name,
+                occupant_id,
+                real_jid as "real_jid [jid]",
+                time,
+                kind,
+                message,
+                error as "error [common_error]",
+                additional_data,
+                stanza_id,
+                message_id,
+                marker as "marker [marker]"
             FROM logs NATURAL JOIN jids WHERE jid IN ({jids})
             AND account_id = {account_id}
             AND kind NOT IN ({kinds})
@@ -518,10 +545,19 @@ class MessageArchiveStorage(SqliteStorage):
         kinds = map(str, [KindConstant.ERROR])
 
         sql = '''
-            SELECT contact_name, time, kind, show, message, subject,
-                   additional_data, log_line_id, message_id, stanza_id,
-                   error as "error [common_error]",
-                   marker as "marker [marker]"
+            SELECT
+                log_line_id,
+                contact_name,
+                occupant_id,
+                real_jid as "real_jid [jid]",
+                time,
+                kind,
+                message,
+                error as "error [common_error]",
+                additional_data,
+                stanza_id,
+                message_id,
+                marker as "marker [marker]"
             FROM logs NATURAL JOIN jids WHERE jid IN ({jids})
             AND account_id = {account_id}
             AND kind NOT IN ({kinds})
@@ -540,9 +576,9 @@ class MessageArchiveStorage(SqliteStorage):
                    account: str,
                    jid: JID,
                    query: str,
-                   from_users: Optional[list[str]] = None,
-                   before: Optional[datetime.datetime] = None,
-                   after: Optional[datetime.datetime] = None
+                   from_users: list[str] | None = None,
+                   before: datetime.datetime | None = None,
+                   after: datetime.datetime | None = None
                    ) -> Iterator[SearchLogRow]:
         '''
         Search the conversation log for messages containing the `query` string.
@@ -626,9 +662,9 @@ class MessageArchiveStorage(SqliteStorage):
     @timeit
     def search_all_logs(self,
                         query: str,
-                        from_users: Optional[list[str]] = None,
-                        before: Optional[datetime.datetime] = None,
-                        after: Optional[datetime.datetime] = None
+                        from_users: list[str] | None = None,
+                        before: datetime.datetime | None = None,
+                        after: datetime.datetime | None = None
                         ) -> Iterator[SearchLogRow]:
         '''
         Search all conversation logs for messages containing the `query`
@@ -736,7 +772,7 @@ class MessageArchiveStorage(SqliteStorage):
     def get_last_history_timestamp(self,
                                    account: str,
                                    jid: str
-                                   ) -> Optional[float]:
+                                   ) -> float | None:
         '''
         Get the timestamp of the last message we received for the jid
         '''
@@ -762,7 +798,7 @@ class MessageArchiveStorage(SqliteStorage):
     def get_first_history_timestamp(self,
                                     account: str,
                                     jid: str
-                                    ) -> Optional[float]:
+                                    ) -> float | None:
         '''
         Get the timestamp of the first message we received for the jid
         '''
@@ -789,7 +825,7 @@ class MessageArchiveStorage(SqliteStorage):
                          account: str,
                          jid: str,
                          date: datetime.datetime
-                         ) -> Optional[float]:
+                         ) -> float | None:
         '''
         Get a single timestamp of a message for 'jid'
         in time range of one day
@@ -818,7 +854,7 @@ class MessageArchiveStorage(SqliteStorage):
                                         account: str,
                                         jid: str,
                                         date: datetime.datetime
-                                        ) -> Optional[MessageMetaRow]:
+                                        ) -> MessageMetaRow | None:
         '''
         Load meta data for the first message of a specific date
         '''
@@ -949,7 +985,7 @@ class MessageArchiveStorage(SqliteStorage):
                                      account: str,
                                      jid: JID,
                                      message_id: str
-                                     ) -> Optional[LastConversationRow]:
+                                     ) -> LastConversationRow | None:
         '''
         Load the last correctable message of a conversation by message_id.
         Conditions: max 5 min old
@@ -976,7 +1012,7 @@ class MessageArchiveStorage(SqliteStorage):
     def try_message_correction(self,
                                account: str,
                                jid: JID,
-                               nickname: Optional[str],
+                               nickname: str | None,
                                corrected_text: str,
                                correct_id: str,
                                kind: KindConstant,
@@ -1130,7 +1166,7 @@ class MessageArchiveStorage(SqliteStorage):
 
     def insert_jid(self,
                    jid: str,
-                   kind: Optional[KindConstant] = None,
+                   kind: KindConstant | None = None,
                    type_: JIDConstant = JIDConstant.NORMAL_TYPE
                    ) -> int:
         '''
@@ -1275,7 +1311,7 @@ class MessageArchiveStorage(SqliteStorage):
         self._delayed_commit()
 
     @timeit
-    def get_archive_infos(self, jid: str) -> Optional[LastArchiveMessageRow]:
+    def get_archive_infos(self, jid: str) -> LastArchiveMessageRow | None:
         '''
         Get the archive infos
 
@@ -1325,7 +1361,7 @@ class MessageArchiveStorage(SqliteStorage):
 
             args = ' = ?, '.join(kwargs.keys()) + ' = ?'
             sql = '''UPDATE last_archive_message SET {}
-                     WHERE jid_id = ?'''.format(args)
+                     WHERE jid_id = ?'''.format(args)  # noqa: UP032
             self._con.execute(sql, tuple(kwargs.values()) + (jid_id,))
         log.info('Set message archive info: %s %s', jid, kwargs)
         self._delayed_commit()
