@@ -36,12 +36,11 @@
 from __future__ import annotations
 
 from typing import Any
-from typing import Callable
 from typing import cast
-from typing import Optional
 
 import os
 import sys
+from collections.abc import Callable
 from datetime import datetime
 from datetime import timedelta
 from datetime import timezone
@@ -65,12 +64,14 @@ from gajim.common import ged
 from gajim.common import idle
 from gajim.common.application import CoreApplication
 from gajim.common.const import GAJIM_FAQ_URI
+from gajim.common.const import GAJIM_PRIVACY_POLICY_URI
 from gajim.common.const import GAJIM_SUPPORT_JID
 from gajim.common.const import GAJIM_WIKI_URI
 from gajim.common.exceptions import GajimGeneralException
 from gajim.common.helpers import load_json
 from gajim.common.helpers import open_uri
 from gajim.common.i18n import _
+from gajim.common.modules.contacts import ResourceContact
 
 from gajim.gtk import menus
 from gajim.gtk import structs
@@ -193,14 +194,9 @@ class GajimApplication(Gtk.Application, CoreApplication):
             GLib.OptionArg.NONE,
             _('Start a new chat'))
 
-        self.add_main_option(
-            'show', 0,
-            GLib.OptionFlags.NONE,
-            GLib.OptionArg.NONE,
-            _('Show Gajim'))
-
         self.add_main_option_entries(self._get_remaining_entry())
 
+        self.connect('activate', self._on_activate)
         self.connect('handle-local-options', self._handle_local_options)
         self.connect('command-line', self._command_line)
         self.connect('shutdown', self._shutdown)
@@ -343,21 +339,25 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         remote_commands = [
             ('start-chat', GLib.Variant('as', ['', ''])),
-            ('show', None)
         ]
 
-        remaining = options.lookup_value(GLib.OPTION_REMAINING,
-                                         GLib.VariantType.new('as'))
-
         for cmd, parameter in remote_commands:
             if options.contains(cmd):
                 self.activate_action(cmd, parameter)
                 return 0
 
+        remaining = options.lookup_value(GLib.OPTION_REMAINING,
+                                         GLib.VariantType.new('as'))
+
         if remaining is not None:
             self._open_uris(remaining.unpack())
             return 0
 
+        if not options.contains('is-first-startup'):
+            # If no commands have been handled and it's not the first
+            # startup, raise the application.
+            self.activate()
+
         return 0
 
     def _handle_local_options(self,
@@ -373,7 +373,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
             # Incorporate profile name into application id
             # to have a single app instance for each profile.
             profile = profile.get_string()
-            app_id = '%s.%s' % (self.get_application_id(), profile)
+            app_id = f'{self.get_application_id()}.{profile}'
             self.set_application_id(app_id)
             configpaths.set_profile(profile)
 
@@ -383,10 +383,14 @@ class GajimApplication(Gtk.Application, CoreApplication):
                   'The primary instance will handle remote commands')
             return -1
 
+        options.insert_value('is-first-startup',  GLib.Variant('b', True))
         self._core_command_line(options)
         self._startup()
         return -1
 
+    def _on_activate(self, _application: Gtk.Application) -> None:
+        app.window.show()
+
     def _add_app_actions(self) -> None:
         for action in APP_ACTIONS:
             action_name, variant = action
@@ -413,6 +417,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
             ('join-support-chat', self._on_join_support_chat),
             ('about', self._on_about_action),
             ('faq', self._on_faq_action),
+            ('privacy-policy', self._on_privacy_policy_action),
             ('start-chat', self._on_new_chat_action),
             ('accounts', self._on_accounts_action),
             ('add-contact', self._on_add_contact_action),
@@ -423,7 +428,6 @@ class GajimApplication(Gtk.Application, CoreApplication):
             ('forget-groupchat', self._on_forget_groupchat_action),
             ('open-chat', self._on_open_chat_action),
             ('mute-chat', self._on_mute_chat_action),
-            ('show', self._on_show),
         ]
 
         for action in actions:
@@ -525,7 +529,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
     def create_account(self,
                        account: str,
-                       username: str,
+                       username: str | None,
                        domain: str,
                        password: str,
                        proxy_name: str | None,
@@ -595,12 +599,12 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
     @staticmethod
     def _on_preferences_action(_action: Gio.SimpleAction,
-                               _param: Optional[GLib.Variant]) -> None:
+                               _param: GLib.Variant | None) -> None:
         open_window('Preferences')
 
     @staticmethod
     def _on_plugins_action(_action: Gio.SimpleAction,
-                           _param: Optional[GLib.Variant]) -> None:
+                           _param: GLib.Variant | None) -> None:
         open_window('PluginsWindow')
 
     @staticmethod
@@ -619,7 +623,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
     @staticmethod
     def _on_quit_action(_action: Gio.SimpleAction,
-                        _param: Optional[GLib.Variant]) -> None:
+                        _param: GLib.Variant | None) -> None:
         app.window.quit()
 
     @staticmethod
@@ -671,7 +675,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
     @staticmethod
     def _on_add_account_action(_action: Gio.SimpleAction,
-                               _param: Optional[GLib.Variant]) -> None:
+                               _param: GLib.Variant | None) -> None:
         open_window('AccountWizard')
 
     @staticmethod
@@ -717,22 +721,22 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
     @staticmethod
     def _on_xml_console_action(_action: Gio.SimpleAction,
-                               _param: Optional[GLib.Variant]) -> None:
+                               _param: GLib.Variant | None) -> None:
         open_window('XMLConsoleWindow')
 
     @staticmethod
     def _on_manage_proxies_action(_action: Gio.SimpleAction,
-                                  _param: Optional[GLib.Variant]) -> None:
+                                  _param: GLib.Variant | None) -> None:
         open_window('ManageProxies')
 
     @staticmethod
     def _on_content_action(_action: Gio.SimpleAction,
-                           _param: Optional[GLib.Variant]) -> None:
+                           _param: GLib.Variant | None) -> None:
         open_uri(GAJIM_WIKI_URI)
 
     @staticmethod
     def _on_join_support_chat(_action: Gio.SimpleAction,
-                              _param: Optional[GLib.Variant]) -> None:
+                              _param: GLib.Variant | None) -> None:
         accounts = app.settings.get_active_accounts()
         if len(accounts) == 1:
             app.window.show_add_join_groupchat(
@@ -742,27 +746,32 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
     @staticmethod
     def _on_faq_action(_action: Gio.SimpleAction,
-                       _param: Optional[GLib.Variant]) -> None:
+                       _param: GLib.Variant | None) -> None:
         open_uri(GAJIM_FAQ_URI)
 
+    @staticmethod
+    def _on_privacy_policy_action(_action: Gio.SimpleAction,
+                                  _param: GLib.Variant | None) -> None:
+        open_uri(GAJIM_PRIVACY_POLICY_URI)
+
     @staticmethod
     def _on_shortcuts_action(_action: Gio.SimpleAction,
-                             _param: Optional[GLib.Variant]) -> None:
+                             _param: GLib.Variant | None) -> None:
         ShortcutsWindow()
 
     @staticmethod
     def _on_features_action(_action: Gio.SimpleAction,
-                            _param: Optional[GLib.Variant]) -> None:
+                            _param: GLib.Variant | None) -> None:
         open_window('Features')
 
     @staticmethod
     def _on_about_action(_action: Gio.SimpleAction,
-                         _param: Optional[GLib.Variant]) -> None:
+                         _param: GLib.Variant | None) -> None:
         AboutDialog()
 
     @staticmethod
     def _on_file_transfer_action(_action: Gio.SimpleAction,
-                                 _param: Optional[GLib.Variant]) -> None:
+                                 _param: GLib.Variant | None) -> None:
 
         ft = app.interface.instances['file_transfers']
         if ft.window.get_property('visible'):
@@ -827,6 +836,7 @@ class GajimApplication(Gtk.Application, CoreApplication):
 
         client = app.get_client(params.account)
         contact = client.get_module('Contacts').get_contact(params.jid)
+        assert not isinstance(contact, ResourceContact)
 
         if params.state == MuteState.UNMUTE:
             contact.settings.set('mute_until', None)
@@ -842,8 +852,9 @@ class GajimApplication(Gtk.Application, CoreApplication):
                                   ) -> None:
         def _remove() -> None:
             app.storage.archive.remove_history(params.account, params.jid)
-            control = app.window.get_control()
 
+            app.window.clear_chat_list_row(params.account, params.jid)
+            control = app.window.get_control()
             if not control.is_loaded(params.account, params.jid):
                 return
 
@@ -872,7 +883,3 @@ class GajimApplication(Gtk.Application, CoreApplication):
         client.get_module('Bookmarks').remove(params.jid)
 
         app.storage.archive.remove_history(params.account, params.jid)
-
-    @staticmethod
-    def _on_show(_action: Gio.SimpleAction, param: GLib.Variant) -> None:
-        app.window.show()
